##  Definition
Platforms are a group of business capabilities, applications, and technologies that provide common functionalities.
They provide functionality consumed by other applications and microservices to accelerate delivery or provide consistent/common functionality and support a set of capabilities.
